#include <stdio.h>
#include <set>
#include <map>

using namespace std;

map<long long, int> gcache, sqrt4cache, sqrt2cache, minequiv;
int N, i, gxor;

long long SQRT2(long long X) {
	if (sqrt2cache.find(X) != sqrt2cache.end())
		return sqrt2cache[X];
	long long li, ls, mid, Y, ans = -1;
	li = 1;
	ls = 1000000;
	while (li <= ls) {
		mid = (li + ls) / 2;
		Y = mid * mid;
		if (Y <= X) {
			ans = mid;
			li = mid + 1;
		} else
			ls = mid - 1;
	}
	return sqrt2cache[X] = ans;
}

long long SQRT4(long long X) {
	if (sqrt4cache.find(X) != sqrt4cache.end())
		return sqrt4cache[X];
	long long li, ls, mid, Y, ans = -1;
	li = 1;
	ls = 1000;
	while (li <= ls) {
		mid = (li + ls) / 2;
		Y = mid * mid * mid * mid;
		if (Y >= X) {
			ans = mid;
			ls = mid - 1;
		} else
			li = mid + 1;
	}
	return sqrt4cache[X] = ans;
}

int Grundy (long long);

long long FindMinEquivalent(long long X) {
	if (minequiv.find(X) != minequiv.end())
		return minequiv[X];
	long long li, ls, mid, ans = X, sqrt4X = SQRT4(X), sqrt2X = SQRT2(X);
	li = 1; ls = X;
	while (li <= ls) {
		mid = (li + ls) / 2;
		if (SQRT4(mid) == sqrt4X && SQRT2(mid) == sqrt2X) {
		//if (Grundy(SQRT4(mid)) == Grundy(sqrt4X) && Grundy(SQRT2(mid)) == Grundy(sqrt2X)) {
			ans = mid;
			ls = mid - 1;
		} else
			li = mid + 1;
	}	
	return minequiv[X] = ans;
}

int Grundy(long long X) {
//	long long XX = FindMinEquivalent(X);
//	X = XX;
	if (gcache.find(X) != gcache.end())
		return gcache[X];

	long long sqrt4X = SQRT4(X), sqrt2X = SQRT2(X);
	//fprintf(stderr, "### Grundy call: X=%I64d: sqrt4X=%I64d; sqrt2X=%I64d\n", X, sqrt4X, sqrt2X);

	if (sqrt2X == X)
		sqrt2X--;
	
	set<int> gnum;
	for (long long Y = sqrt2X; Y >= sqrt4X;) {
		long long Yequiv = FindMinEquivalent(Y);
		//fprintf(stderr, "MinEquivalent(%I64d)=%I64d (going down to %I64d)\n", Y, Yequiv, sqrt4X);
		if (Yequiv < sqrt4X)
			Yequiv = sqrt4X;
		gnum.insert(Grundy(Yequiv));
		if (gnum.size() >= 3)
			break;
		Y = Yequiv - 1;
	}
	
	int ans = 0;
	for (set<int>::iterator it = gnum.begin(); it != gnum.end(); it++) {
		if (*it == ans)
			ans++;
		else
			break;
	}

	fprintf(stderr, "Grundy result(%I64d)=%d\n", X, ans);
	gcache[X] = ans;
	return ans;
}

int main() {
	long long X;
	
	//freopen("x.txt", "r", stdin);
	scanf("%d", &N);
	gxor = 0;
	for (i = 1; i <= N; i++) {
		scanf("%I64d", &X);
		gxor ^= Grundy(X);
	}
	
	if (gxor > 0)
		printf("Furlo\n");
	else
		printf("Rublo\n");
	return 0;
}
