#include <stdio.h>
#include <math.h>

#define NMAX 3100
#define INF 1000000.0
#define eps 1e-7

double r[NMAX], R[NMAX], h[NMAX], hb[NMAX], hmax;
int N, i, j;

inline double GetR(int a, double hplace) {
	if (hplace > h[a])
		hplace = h[a];
	double dr = R[a] - r[a];
	double result = r[a] + (hplace * dr) / h[a];
	//fprintf(stderr, "GetR(%d,%lf)=%lf\n", a, hplace, result);
	return result;
}

inline int CanPlace(int a, int b, double hplace) {
	double wa1, wa2, wb1, wb2;
	wa1 = GetR(a, hplace);
	wa2 = GetR(a, h[a]);
	wb1 = GetR(b, 0.0);
	wb2 = GetR(b, h[a] - hplace);

	//fprintf(stderr, "(1) a=%d b=%d hplace=%lf: wa1=%lf wb1=%lf wa2=%lf wb2=%lf\n", a, b, hplace, wa1, wb1, wa2, wb2);

	if ((wb1 > wa1 && fabs(wa1 - wb1) > eps) ||
		(wb2 > wa2 && fabs(wa2 - wb2) > eps))
		return 0;

	if (h[a] - hplace > h[b]) {
		wa1 = GetR(a, hplace + h[b]);
		wb1 = GetR(b, h[b]);
		//fprintf(stderr, "(2) a=%d b=%d hplace=%lf: wa1=%lf wb1=%lf\n", a, b, hplace, wa1, wb1);

		if (wb1 > wa1 && fabs(wa1 - wb1) > eps)
			return 0;
	}

	return 1;
}

inline double BottomHeight(int a, int b) {
	double li, ls, mid;
	li = 0.0; ls = h[a];
	while (fabs(ls - li) > eps) {
		mid = 0.5 * (li + ls);
		if (CanPlace(a, b, mid)) {
			ls = mid;
			if (mid + hb[a] < hb[b])
				return mid;
		} else {
			li = mid;
		}
	}

	return li;
}

int main() {
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);

	scanf("%d", &N);
	for (i = 1; i <= N; i++)
		scanf("%lf %lf %lf", &h[i], &r[i], &R[i]);

	hb[1] = 0;
	for (i = 2; i <= N; i++) {
		hb[i] = 0;
		for (j = i - 1; j >= 1; j--) {
			double hbj = BottomHeight(j, i);
			//fprintf(stderr, "bottom %d: top %d => hin=%lf\n", j, i, hbj);

			if (hbj + hb[j] > hb[i])
				hb[i] = hbj + hb[j];
		}
	}

	hmax = 0.0;
	for (i = 1; i <= N; i++)
		if (hb[i] + h[i] > hmax)
			hmax = hb[i] + h[i];

	printf("%.7lf\n", hmax);
		
	return 0;
}
